@@ -14,6 +14,8 @@ import atexit
 import mkchromecast.colors as colors
 
 platform = mkchromecast.__init__.platform
+adevice = mkchromecast.__init__.adevice
+ccname = mkchromecast.__init__.ccname
 
 print(colors.bold('mkchromecast ')+'v'+__version__)
 
@@ -26,9 +28,12 @@ if args.tray == False:
     if cc.ip == '127.0.0.1':        # We verify the local IP.
         print(colors.error('Your computer is not connected to any network'))
         terminate()
+    elif cc.ip != '127.0.0.1' and args.discover == True:
+        cc.initialize_cast()
+        terminate()
 
-    if args.youtube == None:
-        if platform == 'Linux':
+    if args.youtube == None and args.source_url == None:
+        if platform == 'Linux' and adevice == None:
             print('Creating pulseaudio sink...')
             print(colors.warning('Open pavucontrol and select the mkchromecast sink.'))
             create_sink()
@@ -36,7 +41,7 @@ if args.tray == False:
         print(colors.important('Starting local streaming server'))
         print(colors.success('[Done]'))
 
-        if args.encoder_backend == 'node' and platform == 'Darwin':
+        if args.encoder_backend == 'node' and platform == 'Darwin' and args.source_url == None:
             from mkchromecast.node import *
             stream()
 
@@ -45,10 +50,10 @@ if args.tray == False:
             'avconv',
             'parec'
             ]
-        if args.encoder_backend in backends:
+        if args.encoder_backend in backends and args.source_url == None:
             import mkchromecast.audio
             mkchromecast.audio.main()
-    else: # When casting youtube url, we do it throught the audio module
+    elif args.youtube == True: # When casting youtube url, we do it throught the audio module
         import mkchromecast.audio
         mkchromecast.audio.main()
 
@@ -58,7 +63,7 @@ if args.tray == False:
         cc.sel_cc()
         cc.inp_cc()
         cc.get_cc()
-        if platform == 'Darwin':
+        if platform == 'Darwin' and args.source_url == None:
             print('Switching to soundflower...')
             inputdev()
             outputdev()
@@ -66,7 +71,7 @@ if args.tray == False:
         cc.play_cast()
     else:
         cc.get_cc()
-        if platform == 'Darwin' and args.youtube == None:
+        if platform == 'Darwin' and args.youtube == None and args.source_url == None:
             print('Switching to soundflower...')
             inputdev()
             outputdev()
@@ -78,7 +83,7 @@ if args.tray == False:
         if platform == 'Darwin':
             inputint()
             outputint()
-        else:
+        elif platform == 'Linux' and adevice == None:
             remove_sink()
         terminate()
         return
@@ -98,7 +103,7 @@ if args.tray == False:
             print('')
             print(colors.options('Volume up:')+' u')
             print(colors.options('Volume down:')+' d')
-            print(colors.options('Quit the application:')+' q')
+            print(colors.options('Quit the application:')+' q or Ctrl-C')
             print('')
             return
         controls_msg()
@@ -119,11 +124,14 @@ if args.tray == False:
                 elif(key == 'q'):
                     print(colors.error('Quitting application...'))
                     terminateapp()
+                elif(key == '\x03'):
+                    raise KeyboardInterrupt
+                    atexit.register(terminateapp)
         except KeyboardInterrupt:
             terminateapp()
 
     else:
-        if platform == 'Linux':
+        if platform == 'Linux' and adevice == None:
             print(colors.warning('Remember to open pavucontrol and select the mkchromecast sink.'))
         print('')
         print(colors.error('Ctrl-C to kill the application at any time'))
